.. _image-sets:

==============
WWT Image Sets
==============

Images in the AAS WorldWide Telescope can come in a variety of formats:

- Standard bitmapped images like PNG or JPG files
- Scientific data in FITS files
- Large-size images converted into tile pyramids

Such images are described as ``<ImageSet>`` XML fragments in several of the
WWT file formats.
